@@ -11,45 +11,165 @@ Supported scenarios:
   7. wiki: Codebase wiki generation
 """
 
-import click
-import json
 import hashlib
+import json
 from pathlib import Path
-from scenarios import scenario_1_local_snapshot
-from scenarios import scenario_2_repo_adapt
-from scenarios import scenario_3_regression
-from scenarios import scenario_4_arch_drift
-from scenarios import scenario_5_local_rag
-from scenarios import scenario_6_code_review
-from scenarios import scenario_7_codebase_tutorial
+
+import click
+
+from scenarios import (scenario_1_local_snapshot, scenario_2_repo_adapt,
+                       scenario_3_regression, scenario_4_arch_drift,
+                       scenario_5_local_rag, scenario_6_code_review,
+                       scenario_7_codebase_tutorial)
 
 
 class NaturalOrderGroup(click.Group):
-    """Custom Click Group that maintains command order"""
+    """Custom Click Group that maintains command order and formats help"""
     def list_commands(self, ctx):
         return list(self.commands)
 
+    def format_help(self, ctx, formatter):
+        """Custom help formatter that only shows the description"""
+        self.format_usage(ctx, formatter)
+        self.format_help_text(ctx, formatter)
+        # Skip format_options and format_commands to remove Options/Commands sections
+
 @click.group(cls=NaturalOrderGroup, invoke_without_command=True)
 @click.pass_context
 def cli(ctx):
-    """NodeCraft - A modular framework to forge and verify intelligent outcomes.
+    """NodeCraft - A modular framework for building composable AI workflows.
 
     \b
-    Quick Start:
-      nodecraft tutorial                # Getting started guide
-      nodecraft tutorial node           # Create custom nodes
-      nodecraft nodes list              # Discover available nodes
-      nodecraft scenarios list          # See all scenarios
+    ═══════════════════════════════════════════════════════════════════════
+    SETUP (First Time Users)
+    ═══════════════════════════════════════════════════════════════════════
 
     \b
-    Supported scenarios:
-      1. snapshot - Local snapshot and rollback (no GitHub dependency)
-      2. adapt - Open-source repository understanding and adaptation
-      3. regression - Regression detection with diff analysis
-      4. arch-drift - Architecture drift and impact scanning
-      5. rag - Local lightweight RAG (Files-to-Prompt)
-      6. code-review - Code review pipeline (security, quality, performance)
-      7. wiki - Codebase wiki generation
+    1. Install NodeCraft:
+       pip install NodeCraft
+
+    \b
+    2. Configure API Key (choose one):
+       export ANTHROPIC_API_KEY='your-key-here'    # Recommended (Claude)
+       export OPENAI_API_KEY='your-key-here'       # Alternative (GPT)
+
+    \b
+    3. Try your first command:
+       nodecraft tutorial                          # Interactive tutorials
+       nodecraft rag --query "What does this code do?" --patterns "**/*.py"
+
+    \b
+    Supported LLM Models:
+      • Anthropic Claude: claude-3-haiku-20240307, claude-3-5-sonnet-20241022
+      • OpenAI: gpt-4, gpt-4-turbo, gpt-3.5-turbo
+
+    \b
+    Override default model:
+      nodecraft rag --query "..." --model claude-3-5-sonnet-20241022
+      nodecraft arch-drift --model gpt-4-turbo
+
+    \b
+    ═══════════════════════════════════════════════════════════════════════
+    CORE COMMANDS
+    ═══════════════════════════════════════════════════════════════════════
+
+    \b
+    tutorial          Interactive tutorials and guides
+      nodecraft tutorial node            # Node creation tutorial
+      nodecraft tutorial scenario        # Scenario creation tutorial
+
+    \b
+    nodes             Node management and discovery
+      nodecraft nodes list               # List all available nodes
+      nodecraft nodes show <node_id>     # Show node details
+      nodecraft nodes create --name X    # Create new custom node
+      nodecraft nodes register ./path    # Register custom nodes
+
+    \b
+    scenarios         Scenario management and execution
+      nodecraft scenarios list           # List all scenarios
+      nodecraft scenarios show <id>      # Show scenario details
+      nodecraft scenarios run <id>       # Run a scenario
+      nodecraft scenarios create --name X --template rag-query --description "My workflow"
+
+    \b
+    ═══════════════════════════════════════════════════════════════════════
+    BUILT-IN SCENARIOS
+    ═══════════════════════════════════════════════════════════════════════
+
+    \b
+    snapshot          Create snapshots of your codebase for rollback
+      Snapshots are saved to .ai-snapshots/ by default (customizable with --output-dir)
+      Each snapshot creates: snapshot-{timestamp}.json and snapshot-{timestamp}.md
+
+      Use case 1: Create snapshot before making risky changes
+        nodecraft snapshot --patterns "**/*.py" --model claude-3-haiku-20240307
+        nodecraft snapshot --patterns "**/*.py" --patterns "**/*.js"
+      \b
+      Use case 2: Create snapshot with custom location
+        nodecraft snapshot --output-dir ~/project-backups
+        nodecraft snapshot --output-dir ./snapshots --patterns "src/**/*.ts"
+      \b
+      Use case 3: List all snapshots and restore from a previous version
+        nodecraft snapshot-list
+        nodecraft snapshot-list --snapshot-dir ~/project-backups
+        nodecraft snapshot-restore 20251019_025204
+        nodecraft snapshot-restore 20251019_025204 --snapshot-dir ~/project-backups
+
+    \b
+    rag               Ask questions about your codebase (lightweight RAG)
+      Use case 1: Quick codebase overview and architecture understanding
+        nodecraft rag --patterns "**/*.py" --patterns "README.md" \\
+          --query "How does this project work? Please provide an overview of the architecture and core features." \\
+          --format xml --cxml --model claude-3-haiku-20240307
+      \b
+      Use case 2: Generate API documentation from test files
+        nodecraft rag --patterns "tests/**/*.py" \\
+          --query "Based on the test cases, generate API usage documentation for this project" \\
+          --format markdown --model claude-3-haiku-20240307
+
+    \b
+    code-review       AI code review (security, quality, performance)
+      Use case 1: Full code review with all checks
+        nodecraft code-review --git-ref ./your-repo \\
+          --output review_report.yaml --format yaml
+      \b
+      Use case 2: Security-only review for sensitive code
+        nodecraft code-review --git-ref ./your-repo \\
+          --security-only --format markdown
+
+    \b
+    wiki              Generate structured codebase documentation
+      Use case 1: Generate wiki from local codebase
+        nodecraft wiki --local-dir . --output ./wiki_output \\
+          --language english --max-abstractions 8 \\
+          --include-pattern "*.py" --include-pattern "*.md" \\
+          --exclude-pattern "**/__pycache__/*" --exclude-pattern "**/tests/*" \\
+          --model claude-3-haiku-20240307
+      \b
+      Use case 2: Generate wiki from GitHub repository
+        nodecraft wiki --repo https://github.com/The-Pocket/PocketFlow-Rust
+
+    \b
+    adapt             Analyze and adapt open-source repositories
+      Use case: Understand external codebase and generate integration plan
+        nodecraft adapt https://github.com/pallets/click \\
+          --model claude-3-haiku-20240307
+
+    \b
+    regression        AI-powered regression testing and quality gate
+      Use case: Detect regression between two git commits
+        nodecraft regression --baseline "HEAD~1" --build "HEAD" \\
+          --model claude-3-haiku-20240307
+
+    \b
+    arch-drift        Detect architecture violations and drift
+      Use case: Scan for circular dependencies and architecture issues
+        nodecraft arch-drift --model claude-3-haiku-20240307
+
+    \b
+    ═══════════════════════════════════════════════════════════════════════
+    Run 'nodecraft COMMAND --help' for detailed options and examples.
     """
     # If no command specified, show help
     if ctx.invoked_subcommand is None:
@@ -86,46 +206,69 @@ def tutorial_cmd(topic):
         click.echo(get_tutorial(topic))
 
 
-@cli.command()
+@cli.command(short_help="Create AI-powered code snapshot [--patterns **/*.py --model gpt-4]")
 @click.option('--patterns', multiple=True, default=['**/*.py'], help='File matching patterns')
 @click.option('--model', default='gpt-4', help='LLM model')
-def snapshot(patterns, model):
-    """Scenario 1: Local snapshot and rollback (no GitHub dependency)
+@click.option('--output-dir', default='.ai-snapshots', help='Snapshot output directory [default: .ai-snapshots]')
+def snapshot(patterns, model, output_dir):
+    """Create AI-powered code snapshot
 
-    Scan project files, parse code structure, use AI to analyze and create snapshot
+    Scan project files, parse code structure, and use AI to analyze and create snapshot.
+
+    By default, snapshots are saved to .ai-snapshots/ directory in the current project.
+    Each snapshot creates two files:
+      - snapshot-{timestamp}.json (complete snapshot data)
+      - snapshot-{timestamp}.md (AI analysis report)
+
+    \b
+    Examples:
+      nodecraft snapshot
+      nodecraft snapshot --patterns "**/*.py" --patterns "**/*.js"
+      nodecraft snapshot --model claude-3-haiku-20240307
+      nodecraft snapshot --output-dir ./my-snapshots
     """
     click.echo("Scenario 1: Local snapshot and rollback")
     config = {
         'file_patterns': list(patterns),
-        'model': model
+        'model': model,
+        'output_dir': output_dir
     }
     result = scenario_1_local_snapshot.run(config)
     snapshot_id = result.get('snapshot_id')
+    snapshot_file = result.get('snapshot_file', '')
     if snapshot_id:
         click.echo(f"Snapshot created: {snapshot_id}")
+        click.echo(f"Location: {snapshot_file}")
         response = result.get('llm_response', '')
         if response:
             preview = response[:300] + "..." if len(response) > 300 else response
             click.echo(f"\nSnapshot preview:\n{preview}\n")
     else:
-        click.echo("Snapshot created (mock LLM content), see .ai-snapshots/ directory")
+        click.echo(f"Snapshot created (mock LLM content), see {output_dir}/ directory")
 
 
-@cli.command(name='snapshot-list')
-def snapshot_list():
-    """List all snapshots"""
-    snapshots_dir = Path(".ai-snapshots")
+@cli.command(name='snapshot-list', short_help="List all code snapshots [no args]")
+@click.option('--snapshot-dir', default='.ai-snapshots', help='Snapshot directory [default: .ai-snapshots]')
+def snapshot_list(snapshot_dir):
+    """List all code snapshots
+
+    \b
+    Examples:
+      nodecraft snapshot-list
+      nodecraft snapshot-list --snapshot-dir ./my-snapshots
+    """
+    snapshots_dir = Path(snapshot_dir)
     if not snapshots_dir.exists():
-        click.echo("No snapshots found")
+        click.echo(f"No snapshots found in {snapshot_dir}")
         return
 
     snapshot_files = sorted(snapshots_dir.glob("snapshot-*.json"), reverse=True)
 
     if not snapshot_files:
-        click.echo("No snapshots found")
+        click.echo(f"No snapshots found in {snapshot_dir}")
         return
 
-    click.echo("Available Snapshots:\n")
+    click.echo(f"Available Snapshots in {snapshot_dir}:\n")
     for snap_file in snapshot_files:
         try:
             with open(snap_file, 'r') as f:
@@ -138,18 +281,22 @@ def snapshot_list():
             click.echo(f"  [Error] {snap_file.name}: {e}")
 
 
-@cli.command(name='snapshot-restore')
+@cli.command(name='snapshot-restore', short_help="Restore from snapshot [SNAPSHOT_ID]")
 @click.argument('snapshot_id')
-def snapshot_restore(snapshot_id):
+@click.option('--snapshot-dir', default='.ai-snapshots', help='Snapshot directory [default: .ai-snapshots]')
+def snapshot_restore(snapshot_id, snapshot_dir):
     """Restore files from snapshot
 
-    Example: python cli.py snapshot-restore 20250101_120000
+    \b
+    Examples:
+      nodecraft snapshot-restore 20250120_120000
+      nodecraft snapshot-restore 20250120_120000 --snapshot-dir ./my-snapshots
     """
-    snapshot_file = Path(f".ai-snapshots/snapshot-{snapshot_id}.json")
+    snapshot_file = Path(f"{snapshot_dir}/snapshot-{snapshot_id}.json")
 
     if not snapshot_file.exists():
-        click.echo(f"Snapshot not found: {snapshot_id}")
-        click.echo("Run 'python cli.py snapshot-list' to see available snapshots")
+        click.echo(f"Snapshot not found: {snapshot_id} in {snapshot_dir}")
+        click.echo(f"Run 'nodecraft snapshot-list --snapshot-dir {snapshot_dir}' to see available snapshots")
         return
 
     try:
@@ -192,20 +339,20 @@ def snapshot_restore(snapshot_id):
         click.echo(f"Error restoring snapshot: {e}")
 
 
-@cli.command()
+@cli.command(short_help="Analyze GitHub repo and generate adaptation plan [REPO_URL --model gpt-4]")
 @click.argument('repo', required=False)
 @click.option('--model', default='gpt-4', help='LLM model')
 def adapt(repo, model):
-    """Scenario 2: Open-source repository understanding and adaptation
-
-    Analyze open-source repository and generate adaptation plan
+    """Analyze GitHub repo and generate adaptation plan
 
+    \b
     Example:
-      python cli.py adapt https://github.com/pallets/flask
+      nodecraft adapt https://github.com/pallets/flask
+      nodecraft adapt https://github.com/user/repo --model claude-3-haiku-20240307
     """
     if not repo:
         click.echo("Repository URL required")
-        click.echo("Example: python cli.py adapt https://github.com/pallets/flask")
+        click.echo("Example: nodecraft adapt https://github.com/pallets/flask")
         return
 
     click.echo(f"Scenario 2: Repository understanding and adaptation")
@@ -229,16 +376,22 @@ def adapt(repo, model):
                 click.echo(f"\nPlan summary:\n{plan_section}...\n")
 
 
-@cli.command()
+@cli.command(short_help="Detect regressions with AI quality gate [--baseline main~1 --build HEAD]")
 @click.option('--baseline', default='main~1', help='Baseline version (default: main~1)')
 @click.option('--build', default='HEAD', help='Build version (default: HEAD)')
 @click.option('--model', default='gpt-4', help='LLM model')
 @click.option('--pass-rate-min', default=95, help='Minimum test pass rate')
 @click.option('--coverage-drop-max', default=5, help='Maximum coverage drop')
 def regression(baseline, build, model, pass_rate_min, coverage_drop_max):
-    """Scenario 3: Regression detection with diff analysis
+    """Detect regressions with AI quality gate
 
-    Collect test, coverage, and lint metrics; AI evaluates quality gate
+    Collect test, coverage, and lint metrics; AI evaluates quality gate.
+
+    \b
+    Examples:
+      nodecraft regression
+      nodecraft regression --baseline main --build feature-branch
+      nodecraft regression --pass-rate-min 90 --coverage-drop-max 10
     """
     click.echo("Scenario 3: Regression detection")
     click.echo(f"Baseline: {baseline}, Build: {build}")
@@ -262,12 +415,18 @@ def regression(baseline, build, model, pass_rate_min, coverage_drop_max):
                 click.echo(f"\nGate decision:\n" + '\n'.join(lines) + "\n")
 
 
-@cli.command(name='arch-drift')
+@cli.command(name='arch-drift', short_help="Detect architecture drift and violations [--model gpt-4]")
 @click.option('--model', default='gpt-4', help='LLM model')
 def arch_drift(model):
-    """Scenario 4: Architecture drift and impact scanning
+    """Detect architecture drift and violations
 
-    Analyze dependency graph, layer violations, complexity, API breakage; AI audits architecture health
+    Analyze dependency graph, layer violations, complexity, and API breakage.
+    AI audits architecture health.
+
+    \b
+    Examples:
+      nodecraft arch-drift
+      nodecraft arch-drift --model claude-3-haiku-20240307
     """
     click.echo("Scenario 4: Architecture drift scanning")
 
@@ -284,7 +443,7 @@ def arch_drift(model):
                 click.echo(f"\nArchitecture assessment:\n" + '\n'.join(lines) + "\n")
 
 
-@cli.command()
+@cli.command(short_help="Ask questions about your codebase [--query QUESTION --patterns **/*.py]")
 @click.option('--patterns', multiple=True, default=['**/*.py'], help='File matching patterns (can specify multiple)')
 @click.option('--query', required=True, help='Query to ask LLM')
 @click.option('--format', type=click.Choice(['xml', 'markdown']), default='xml', help='Output format')
@@ -292,7 +451,7 @@ def arch_drift(model):
 @click.option('--line-numbers', is_flag=True, help='Include line numbers')
 @click.option('--model', default='claude-3-haiku-20240307', help='LLM model')
 def rag(patterns, query, format, cxml, line_numbers, model):
-    """Scenario 5: Local lightweight RAG (Files-to-Prompt)
+    """Ask questions about your codebase (lightweight RAG)
 
     Quick LLM understanding of codebase and question answering
 
@@ -303,8 +462,8 @@ def rag(patterns, query, format, cxml, line_numbers, model):
       4. Code review: --query "Review code quality"
 
     Examples:
-      python cli.py rag --patterns "**/*.py" --query "What is the project architecture?"
-      python cli.py rag --patterns "tests/**" --query "Generate test documentation" --format markdown
+      nodecraft rag --patterns "**/*.py" --query "What is the project architecture?"
+      nodecraft rag --patterns "tests/**" --query "Generate test documentation" --format markdown
     """
     click.echo("Scenario 5: Local lightweight RAG")
     click.echo(f"File patterns: {', '.join(patterns)}")
@@ -344,7 +503,7 @@ def rag(patterns, query, format, cxml, line_numbers, model):
             click.echo("No response received")
 
 
-@cli.command(name='code-review')
+@cli.command(name='code-review', short_help="AI-powered code review [--git-diff --format yaml]")
 @click.option('--git-diff', is_flag=True, help='Review current git changes')
 @click.option('--git-ref', default=None, help='Git reference to diff against (e.g., HEAD~1, main)')
 @click.option('--diff', 'diff_file', default=None, help='Path to diff/patch file')
@@ -352,15 +511,16 @@ def rag(patterns, query, format, cxml, line_numbers, model):
 @click.option('--format', 'output_format', type=click.Choice(['yaml', 'json', 'markdown']), default='yaml', help='Output format')
 @click.option('--security-only', is_flag=True, help='Only run security checks')
 def code_review(git_diff, git_ref, diff_file, output, output_format, security_only):
-    """Scenario 6: Code review pipeline (security, quality, performance)
+    """AI-powered code review (security, quality, performance)
 
-    Reviews code changes for security, quality, and performance issues.
+    Reviews code changes for security vulnerabilities, quality issues, and performance problems.
 
+    \b
     Examples:
-      python cli.py code-review --git-diff
-      python cli.py code-review --git-ref HEAD~1 --output review.yaml
-      python cli.py code-review --diff changes.patch --format markdown
-      python cli.py code-review --git-diff --security-only
+      nodecraft code-review --git-diff
+      nodecraft code-review --git-ref HEAD~1 --output review.yaml
+      nodecraft code-review --diff changes.patch --format markdown
+      nodecraft code-review --git-diff --security-only
     """
     click.echo("Scenario 6: Code review pipeline")
     click.echo("=" * 80)
@@ -469,7 +629,7 @@ def code_review(git_diff, git_ref, diff_file, output, output_format, security_on
     click.echo("=" * 80)
 
 
-@cli.command()
+@cli.command(short_help="Generate wiki documentation from codebase [--repo URL or --local-dir PATH]")
 @click.option('--repo', default=None, help='GitHub repository URL')
 @click.option('--local-dir', default=None, help='Local directory path')
 @click.option('--output', default='output', help='Output directory')
@@ -480,15 +640,16 @@ def code_review(git_diff, git_ref, diff_file, output, output_format, security_on
 @click.option('--include-pattern', multiple=True, help='File patterns to include (can specify multiple)')
 @click.option('--exclude-pattern', multiple=True, help='File patterns to exclude (can specify multiple)')
 def wiki(repo, local_dir, output, model, language, max_abstractions, multi_file, include_pattern, exclude_pattern):
-    """Scenario 7: Codebase wiki generation
+    """Generate wiki documentation from codebase
 
-    Generate structured wiki documentation from codebase (GitHub repo or local directory)
+    Generate structured wiki documentation from GitHub repository or local directory.
 
+    \b
     Examples:
-      python cli.py wiki --repo https://github.com/The-Pocket/PocketFlow-Rust
-      python cli.py wiki --local-dir ./my-project --language chinese
-      python cli.py wiki --repo https://github.com/pallets/flask --max-abstractions 15
-      python cli.py wiki --local-dir . --multi-file --output ./docs
+      nodecraft wiki --repo https://github.com/user/project
+      nodecraft wiki --local-dir ./my-project --language chinese
+      nodecraft wiki --repo https://github.com/pallets/flask --max-abstractions 15
+      nodecraft wiki --local-dir . --multi-file --output ./docs
     """
     click.echo("Scenario 7: Codebase wiki generation")
     click.echo("=" * 80)
@@ -497,8 +658,8 @@ def wiki(repo, local_dir, output, model, language, max_abstractions, multi_file,
     if not repo and not local_dir:
         click.echo("Error: Either --repo or --local-dir must be specified")
         click.echo("\nExamples:")
-        click.echo("  python cli.py wiki --repo https://github.com/The-Pocket/PocketFlow-Rust")
-        click.echo("  python cli.py wiki --local-dir ./my-project")
+        click.echo("  nodecraft wiki --repo https://github.com/The-Pocket/PocketFlow-Rust")
+        click.echo("  nodecraft wiki --local-dir ./my-project")
         return
 
     if repo:
@@ -581,14 +742,73 @@ def wiki(repo, local_dir, output, model, language, max_abstractions, multi_file,
 # Nodes command group
 @cli.group(name='nodes')
 def nodes():
-    """Manage and discover nodes
+    """Node Management - Discover, create, and manage workflow building blocks
+
+    Nodes are the fundamental building blocks in NodeCraft. Each node performs
+    a single, well-defined operation (e.g., fetch files, call LLM, parse code).
 
     \b
-    Examples:
-      nodecraft nodes list                        # List all nodes
-      nodecraft nodes list --namespace custom     # List custom nodes only
-      nodecraft nodes show @common/get_files      # Show node details
-      nodecraft nodes create --name my_analyzer   # Create new node
+    ═══════════════════════════════════════════════════════════════════════
+    DISCOVER NODES
+    ═══════════════════════════════════════════════════════════════════════
+
+    \b
+    List all available nodes:
+      nodecraft nodes list
+      nodecraft nodes list --namespace common     # Only built-in nodes
+      nodecraft nodes list --namespace custom     # Only custom nodes
+      nodecraft nodes list --format json          # JSON output
+
+    \b
+    Show detailed node information:
+      nodecraft nodes show @common/get_files      # Show specific node
+      nodecraft nodes show @common/call_llm       # Show LLM caller node
+
+    \b
+    ═══════════════════════════════════════════════════════════════════════
+    CREATE CUSTOM NODES
+    ═══════════════════════════════════════════════════════════════════════
+
+    \b
+    Create a simple function-based node:
+      nodecraft nodes create --name my_analyzer --output-dir ~/.nodecraft/nodes
+        # --name: Node identifier (used with @custom/my_analyzer)
+        # --output-dir: Where to save the file (default: current directory)
+
+      nodecraft nodes create --name file_processor --description "Process files" --output-dir ~/.nodecraft/nodes
+        # --description: Human-readable description of what the node does
+
+    \b
+    Create a class-based node (for complex logic):
+      nodecraft nodes create --name api_client --type class --output-dir ~/.nodecraft/nodes
+        # --type: Node type (function or class, default: function)
+
+      nodecraft nodes create --name data_transformer --type class --namespace myteam --output-dir ~/.nodecraft/nodes
+        # --namespace: Organize nodes by team/project (default: custom)
+
+    \b
+    Preview without creating:
+      nodecraft nodes create --name test_node --description "Test node" --dry-run
+        # --dry-run: Preview the generated code without creating files
+
+    \b
+    ═══════════════════════════════════════════════════════════════════════
+    REGISTER CUSTOM NODES
+    ═══════════════════════════════════════════════════════════════════════
+
+    \b
+    Register a single node file:
+      nodecraft nodes register ./my_custom_node.py
+      nodecraft nodes register ~/.nodecraft/nodes/analyzer.py
+
+    \b
+    Register all nodes in a directory:
+      nodecraft nodes register ./custom_nodes/ --recursive
+      nodecraft nodes register ~/my-nodes/ --namespace myteam --recursive
+
+    \b
+    ═══════════════════════════════════════════════════════════════════════
+    Use 'nodecraft nodes COMMAND --help' for detailed command options.
     """
     pass
 
@@ -717,7 +937,7 @@ def nodes_show(node_id):
 
 
 @nodes.command(name='create')
-@click.option('--name', required=True, help='Node name (e.g., my_analyzer)')
+@click.option('--name', help='Node name (e.g., my_analyzer)')
 @click.option('--namespace', default='custom', help='Namespace [default: custom]')
 @click.option('--type', 'node_type', default='function',
               type=click.Choice(['function', 'class']),
@@ -725,15 +945,24 @@ def nodes_show(node_id):
 @click.option('--description', help='Node description [interactive if not provided]')
 @click.option('--output-dir', help='Output directory [default: ~/.nodecraft/nodes/]')
 @click.option('--dry-run', is_flag=True, help='Preview without creating files')
-def nodes_create(name, namespace, node_type, description, output_dir, dry_run):
+@click.option('--preview-template', is_flag=True, help='Show template content preview')
+def nodes_create(name, namespace, node_type, description, output_dir, dry_run, preview_template):
     """Create a new node from template
 
     \b
     Examples:
       nodecraft nodes create --name my_analyzer
       nodecraft nodes create --name api_caller --type class
+      nodecraft nodes create --preview-template --type function
     """
     from core.template_generator import NodeTemplateGenerator
+    from core.template_helpers import (
+        visualize_node_structure,
+        validate_node_file,
+        display_validation_result,
+        get_enhanced_next_steps,
+        preview_template as show_template_preview
+    )
 
     generator = NodeTemplateGenerator()
 
@@ -744,6 +973,18 @@ def nodes_create(name, namespace, node_type, description, output_dir, dry_run):
         click.echo(f"{marker} {tmpl_name}: {tmpl_desc}")
     click.echo()
 
+    # Preview template mode
+    if preview_template:
+        preview_content = show_template_preview(node_type, 'node')
+        click.echo(preview_content)
+        return
+
+    # Name is required for actual creation
+    if not name:
+        click.echo("Error: --name is required (or use --preview-template to preview)")
+        click.echo("\nExample: nodecraft nodes create --name my_analyzer")
+        return
+
     # Interactive prompt for description if not provided
     if not description:
         description = click.prompt('Node description', default='Custom node')
@@ -771,12 +1012,28 @@ def nodes_create(name, namespace, node_type, description, output_dir, dry_run):
             output_dir=output_dir
         )
 
-        click.echo(f"Created: {output_file}")
-        click.echo()
-        click.echo("Next steps:")
-        click.echo("  1. Edit the file to implement prep/exec/post logic")
-        click.echo(f"  2. Test: nodecraft nodes show @{namespace}/{name}")
-        click.echo(f"  3. Use in scenarios: @{namespace}/{name}")
+        # Success message with file info
+        click.echo(f"\n[OK] Created: {output_file}")
+        click.echo(f"Template: {node_type} (simple, recommended)")
+
+        # Show structure visualization
+        structure = visualize_node_structure(output_file)
+        click.echo(structure)
+
+        # Validate the generated file
+        is_valid, errors, warnings = validate_node_file(output_file)
+        validation_result = display_validation_result(is_valid, errors, warnings)
+        click.echo(validation_result)
+
+        # Show enhanced next steps
+        next_steps = get_enhanced_next_steps(
+            file_type='node',
+            name=name,
+            namespace=namespace,
+            output_file=output_file,
+            template_type=node_type
+        )
+        click.echo(next_steps)
 
     except FileExistsError as e:
         click.echo(f"Error: {e}", err=True)
@@ -846,17 +1103,98 @@ def nodes_register(path, namespace, recursive):
 @click.option('--description', help='Scenario description (for create action)')
 @click.option('--output-dir', help='Output directory (for create action)')
 @click.option('--dry-run', is_flag=True, help='Preview without creating files (for create action)')
+@click.option('--preview-template', is_flag=True, help='Show template content preview (for create action)')
 @click.option('--recursive', is_flag=True, help='Recursively scan directory (for register action)')
-def scenarios_cmd(action, scenario_id, output_format, params, with_context, context_patterns, context_query, name, template, description, output_dir, dry_run, recursive):
-    """Manage and discover scenarios
+def scenarios_cmd(action, scenario_id, output_format, params, with_context, context_patterns, context_query, name, template, description, output_dir, dry_run, preview_template, recursive):
+    """Scenario Management - Compose nodes into workflows
+
+    Scenarios are workflows that chain multiple nodes together to accomplish
+    complex tasks. Define them in YAML or Python.
 
     \b
-    Examples:
-      nodecraft scenarios list                    # List all scenarios
-      nodecraft scenarios show simple_rag         # Show scenario details
+    ═══════════════════════════════════════════════════════════════════════
+    DISCOVER SCENARIOS
+    ═══════════════════════════════════════════════════════════════════════
+
+    \b
+    List all available scenarios:
+      nodecraft scenarios list
+      nodecraft scenarios list --format json      # JSON output
+
+    \b
+    Show detailed scenario information:
+      nodecraft scenarios show simple_rag         # Show workflow steps
+      nodecraft scenarios show file_collector     # Show parameters
+      nodecraft scenarios show code_analysis      # Show node chain
+
+    \b
+    ═══════════════════════════════════════════════════════════════════════
+    RUN SCENARIOS
+    ═══════════════════════════════════════════════════════════════════════
+
+    \b
+    Run a scenario with parameters:
       nodecraft scenarios run simple_rag --params '{"query": "What does this code do?"}'
+      nodecraft scenarios run file_collector --params '{"patterns": ["*.py", "*.js"]}'
+
+    \b
+    Run with RAG context injection:
+      nodecraft scenarios run simple_rag --with-context \\
+        --context-patterns "**/*.py" \\
+        --context-query "Summarize the architecture"
+
+    \b
+    ═══════════════════════════════════════════════════════════════════════
+    CREATE CUSTOM SCENARIOS
+    ═══════════════════════════════════════════════════════════════════════
+
+    \b
+    Create from templates:
+      nodecraft scenarios create --name my_workflow --template rag-query --description "RAG workflow" --output-dir ~/.nodecraft/scenarios
+        # --name: Scenario identifier (used in CLI commands)
+        # --template: Template type (see available templates below)
+        # --description: Human-readable description of the scenario
+        # --output-dir: Where to save the file (default: current directory)
+
+      nodecraft scenarios create --name analyzer --template analyze-report --description "Code analyzer" --output-dir ~/.nodecraft/scenarios
+
+      nodecraft scenarios create --name custom_flow --template custom --description "Custom workflow" --output-dir ./workflows
+
+    \b
+    Available templates:
+      - rag-query:        RAG-based Q&A workflow
+      - file-process:     File collection and processing
+      - analyze-report:   Code analysis with report generation
+      - gate-check:       Quality gate enforcement
+      - snapshot-restore: Version control and rollback
+      - custom:           Blank template for custom workflows
+
+    \b
+    Preview template without creating:
+      nodecraft scenarios create --name test --template rag-query --description "Test" --dry-run
+        # --dry-run: Preview the generated YAML without creating files
+
+    \b
+    ═══════════════════════════════════════════════════════════════════════
+    REGISTER CUSTOM SCENARIOS
+    ═══════════════════════════════════════════════════════════════════════
+
+    \b
+    Register a scenario file:
+      nodecraft scenarios register ./my_scenario.yaml
+      nodecraft scenarios register ~/.nodecraft/scenarios/custom.yaml
+
+    \b
+    Register all scenarios in a directory:
+      nodecraft scenarios register ./workflows/ --recursive
+      nodecraft scenarios register ~/my-scenarios/ --recursive
+
+    \b
+    ═══════════════════════════════════════════════════════════════════════
+    For built-in scenarios (snapshot, rag, wiki, etc.), use direct commands.
+    Example: 'nodecraft rag --query "question"' instead of scenarios run.
     """
-    from core import scenario_registry, node_registry
+    from core import node_registry, scenario_registry
 
     # Auto-discover nodes and scenarios
     try:
@@ -1013,7 +1351,8 @@ def scenarios_cmd(action, scenario_id, output_format, params, with_context, cont
                 click.echo()
 
                 # Use context injection
-                from core.context_integration import inject_context_to_scenario_run
+                from core.context_integration import \
+                    inject_context_to_scenario_run
 
                 context_config = {
                     "enabled": True,
@@ -1057,12 +1396,13 @@ def scenarios_cmd(action, scenario_id, output_format, params, with_context, cont
 
     elif action == 'create':
         from core.template_generator import ScenarioTemplateGenerator
-
-        # Name is required for create
-        if not name:
-            click.echo("Error: --name is required for create action")
-            click.echo("\nExample: nodecraft scenarios create --name my_workflow --template rag-query")
-            return
+        from core.template_helpers import (
+            visualize_workflow,
+            validate_scenario_file,
+            display_validation_result,
+            get_enhanced_next_steps,
+            preview_template as show_template_preview
+        )
 
         generator = ScenarioTemplateGenerator()
 
@@ -1073,6 +1413,18 @@ def scenarios_cmd(action, scenario_id, output_format, params, with_context, cont
             click.echo(f"{marker} {tmpl_name}: {tmpl_desc}")
         click.echo()
 
+        # Preview template mode
+        if preview_template:
+            preview_content = show_template_preview(template, 'scenario')
+            click.echo(preview_content)
+            return
+
+        # Name is required for actual creation
+        if not name:
+            click.echo("Error: --name is required for create action (or use --preview-template to preview)")
+            click.echo("\nExample: nodecraft scenarios create --name my_workflow --template rag-query")
+            return
+
         # Interactive prompt for description if not provided
         if not description:
             description = click.prompt('Scenario description', default='Custom workflow')
@@ -1098,12 +1450,28 @@ def scenarios_cmd(action, scenario_id, output_format, params, with_context, cont
                 output_dir=output_dir
             )
 
-            click.echo(f"Created: {output_file}")
-            click.echo()
-            click.echo("Next steps:")
-            click.echo("  1. Edit the YAML to customize workflow steps")
-            click.echo(f"  2. Test: nodecraft scenarios show {name}")
-            click.echo(f"  3. Run: nodecraft {name} [OPTIONS]")
+            # Success message with file info
+            click.echo(f"\n[OK] Created: {output_file}")
+            click.echo(f"Template: {template}")
+
+            # Show workflow visualization
+            workflow_viz = visualize_workflow(output_file)
+            click.echo(workflow_viz)
+
+            # Validate the generated file
+            is_valid, errors, warnings = validate_scenario_file(output_file)
+            validation_result = display_validation_result(is_valid, errors, warnings)
+            click.echo(validation_result)
+
+            # Show enhanced next steps
+            next_steps = get_enhanced_next_steps(
+                file_type='scenario',
+                name=name,
+                namespace='',  # scenarios don't have namespace
+                output_file=output_file,
+                template_type=template
+            )
+            click.echo(next_steps)
 
         except FileExistsError as e:
             click.echo(f"Error: {e}", err=True)
@@ -1171,8 +1539,8 @@ def scenarios_cmd(action, scenario_id, output_format, params, with_context, cont
 def _register_dynamic_scenario_commands():
     """Register dynamic CLI commands from YAML scenarios"""
     try:
-        from core.dynamic_cli import register_dynamic_commands
         from core import node_registry, scenario_registry
+        from core.dynamic_cli import register_dynamic_commands
 
         register_dynamic_commands(cli, scenario_registry, node_registry)
     except Exception as e:
