@@ -2,7 +2,7 @@ from engine import node
 from utils.ast_parser import parse_file
 
 def parse_code_node():
-    """解析代码生成 AST 节点"""
+    """Parse code files and generate AST nodes"""
     def prep(ctx, params):
         files = ctx.get("files", [])
         language = params.get("language", "auto")
